@@ -1,8 +1,8 @@
 package Crypt::SecretBuffer;
 # VERSION
 # ABSTRACT: Prevent accidentally leaking a string of sensitive data
-$Crypt::SecretBuffer::VERSION = '0.017_001'; # TRIAL
-$Crypt::SecretBuffer::VERSION = '0.017001';
+$Crypt::SecretBuffer::VERSION = '0.017_002'; # TRIAL
+$Crypt::SecretBuffer::VERSION = '0.017002';
 
 use strict;
 use warnings;
@@ -19,34 +19,25 @@ bootstrap Crypt::SecretBuffer;
 
 {
    package Crypt::SecretBuffer::Exports;
-$Crypt::SecretBuffer::Exports::VERSION = '0.017_001'; # TRIAL
-$Crypt::SecretBuffer::Exports::VERSION = '0.017001';
-use Exporter 'import';
+$Crypt::SecretBuffer::Exports::VERSION = '0.017_002'; # TRIAL
+$Crypt::SecretBuffer::Exports::VERSION = '0.017002';
+   use Exporter 'import';
    @Crypt::SecretBuffer::Exports::EXPORT_OK= qw(
       secret_buffer secret span unmask_secrets_to memcmp
       NONBLOCK AT_LEAST ISO8859_1 ASCII UTF8 UTF16LE UTF16BE HEX BASE64
       MATCH_MULTI MATCH_REVERSE MATCH_NEGATE MATCH_ANCHORED
    );
-   *NONBLOCK=       *Crypt::SecretBuffer::NONBLOCK;
-   *AT_LEAST=       *Crypt::SecretBuffer::AT_LEAST;
-   *ISO8859_1=      *Crypt::SecretBuffer::ISO8859_1;
-   *ASCII=          *Crypt::SecretBuffer::ASCII;
-   *UTF8=           *Crypt::SecretBuffer::UTF8;
-   *UTF16LE=        *Crypt::SecretBuffer::UTF16LE;
-   *UTF16BE=        *Crypt::SecretBuffer::UTF16BE;
-   *HEX=            *Crypt::SecretBuffer::HEX;
-   *BASE64=         *Crypt::SecretBuffer::BASE64;
-   *MATCH_MULTI=    *Crypt::SecretBuffer::MATCH_MULTI;
-   *MATCH_REVERSE=  *Crypt::SecretBuffer::MATCH_REVERSE;
-   *MATCH_NEGATE=   *Crypt::SecretBuffer::MATCH_NEGATE;
-   *MATCH_ANCHORED= *Crypt::SecretBuffer::MATCH_ANCHORED;
 }
 
+# Some of the exported functions are not methods, so instead of having them in the object's
+# namespace I put them in the ::Exports namespace.  Importing from Crypt::SecretBuffer is
+# equivalent to importing from Crypt::SecretBuffer::Exports.
 sub import {
    splice(@_, 0, 1, 'Crypt::SecretBuffer::Exports');
    goto \&Crypt::SecretBuffer::Exports::import;
 }
 
+# For "use Inline -with => 'Crypt::SecretBuffer';" but lazy-load the data.
 sub Inline {
    require Crypt::SecretBuffer::Install::Files;
    goto \&Crypt::SecretBuffer::Install::Files::Inline;
@@ -544,6 +535,35 @@ L<Span object|Crypt::SecretBuffer::Span> and then call its methods.
 Compare contents of the buffer byte-by-byte to another SecretBuffer (or Span, or plain scalar)
 in the same manner as the C function C<memcmp>.  (returns C<< <0 >>, C<0>, or C<< >0 >>)
 
+=head2 append_lenprefixed
+
+  $buf->append_lenprefixed(@byte_strings);
+
+Append one or more strings (which can be a SecretBuffer, L<Span|Crypt::SecretBuffer::Span>, or
+plain scalar of bytes) to the buffer, prefixing each with a variable-length encoding of the
+number of bytes that follows.
+The variable length encoding is base128 big-endian, the same as implemented in
+C<< pack('w',...) >>.  In other words,
+
+  for (@byte_strings) {
+    my $len= ref($_)? $_->length : length($_);
+    $buf->append(pack("w", $len))->append($_);
+  }
+
+See L<Crypt::SecretBuffer::Span/parse_lenprefixed> for the decoding routine.
+
+=head2 append_base128be
+
+Append a variable-length integer encoded as base128 big-endian.  (same as C<< pack('w') >>)
+
+=head2 append_base128le
+
+Append a variable-length integer encoded as base128 little-endian.
+
+=head2 append_asn1_der_length
+
+Append a variable-length integer encoded as the format used by ASN.1 DER for element lengths.
+
 =head2 append_random
 
   $byte_count= $buf->append_random($n_bytes);
@@ -892,7 +912,7 @@ instructions how to report security vulnerabilities.
 
 =head1 VERSION
 
-version 0.017_001
+version 0.017_002
 
 =head1 AUTHOR
 
