@@ -1,8 +1,8 @@
 package Crypt::SecretBuffer::PEM;
 # VERSION
 # ABSTRACT: Parse PEM format from a SecretBuffer
-$Crypt::SecretBuffer::PEM::VERSION = '0.017_001'; # TRIAL
-$Crypt::SecretBuffer::PEM::VERSION = '0.017001';
+$Crypt::SecretBuffer::PEM::VERSION = '0.017_002'; # TRIAL
+$Crypt::SecretBuffer::PEM::VERSION = '0.017002';
 use strict;
 use warnings;
 use Carp;
@@ -117,16 +117,19 @@ sub serialize {
       while (@header_kv) {
          my ($k, $v)= splice @header_kv, 0, 2;
          # Sanity checks, key cannot contain control chars or ':'
-         croak "PEM Header name cannot contain ':' or control characters"
+         croak "PEM Header name '$k' contains ':' or control characters"
             if $k =~ /[\0-\x1F:]/;
-         croak "PEM value cannot contain newline"
+         croak "PEM header value for '$k' must be defined"
+            unless defined $v;
+         croak "PEM header value for '$k' contains a newline"
             if blessed($v) && $v->can('scan')? $v->scan("\n") : $v =~ /\n/;
          $out->append("$k: ")->append($v)->append("\n");
       }
       $out->append("\n"); # empty line terminates headers
    }
-   span($self->content)->append_to($out, encoding => BASE64);
-   $out->append(($self->content->length? "\n" : '')
+   my $content_span= span($self->content);
+   $content_span->append_to($out, encoding => BASE64);
+   $out->append(($content_span->length? "\n" : '')
                 .'-----END '.$self->label."-----\n");
    return $out;
 }
@@ -242,7 +245,7 @@ falling back to the L</headers> hashref.
 
 =head1 VERSION
 
-version 0.017_001
+version 0.017_002
 
 =head1 AUTHOR
 
