@@ -1,8 +1,8 @@
 package Crypt::SecretBuffer::Span;
 # VERSION
 # ABSTRACT: Reference a span of bytes within a SecretBuffer
-$Crypt::SecretBuffer::Span::VERSION = '0.017_001'; # TRIAL
-$Crypt::SecretBuffer::Span::VERSION = '0.017001';
+$Crypt::SecretBuffer::Span::VERSION = '0.017_002'; # TRIAL
+$Crypt::SecretBuffer::Span::VERSION = '0.017002';
 use strict;
 use warnings;
 use Crypt::SecretBuffer; # loads XS methods into this package
@@ -138,6 +138,11 @@ Read-only; this determines how characters will be iterated within the SecretBuff
 This carries over to Span objects created from this span.
 See L<Crypt::SecretBuffer/Character Encodings>.
 
+=head2 last_error
+
+Some parse functions return C<undef> on failure and set this attribute to something more
+informative.  Only check this attribute after one of those parse functions has failed.
+
 =head1 METHODS
 
 =head2 parse
@@ -185,6 +190,45 @@ Only remove from the end of the Span
 
 =back
 
+=head2 parse_lenprefixed
+
+  $span= $span->parse_lenprefixed # count=1
+    or croak $span->last_error;
+  @spans= $span->parse_lenprefixed($count)
+    or croak $span->last_error;
+  @spans= $span->parse_lenprefixed(-1);
+
+Parse one or more length-prefixed spans from the start of this span, returning a list of Span
+objects and updating C<pos> if fully successful.  This first parses a variable-length
+Base128-BigEndian integer, then ensures that there are that many bytes remaining in the span,
+then creates a Span object describing those bytes and advances C<pos> and possibly repeats.
+If the variable-length intgeer is malformed, or not enough bytes remain for the span, the method
+returns an empty list and sets the L</last_error> attribute.
+If you request a count greater than one, all the attempts must succeed or the method returns an
+empty list and sets C<last_error>.  Requesting a count of C<-1> means to consume the remainder
+of the span, which must terminate cleanly at the end of a length-prefixed string.
+
+=head2 parse_base128be
+
+  $len= $span->parse_base128be;
+
+Parse a big-endian base128 encoding where the high-bit indicates continuation, same as
+C<< unpack 'w' >>.  On failure, returns C<undef> and sets L</last_error>.
+
+=head2 parse_base128le
+
+  $len= $span->parse_base128le;
+
+Parse a little-endian base128 encoding where the high-bit indicates continuation, such as used
+by Google Protocol Buffers.  On failure, returns C<undef> and sets L</last_error>.
+
+=head2 parse_asn1_der_length
+
+  $len= $span->parse_asn1_der_length;
+
+Parse the variable-length integer used by ASN.1 DER encoding for the length of an element.
+On failure, returns C<undef> and sets L</last_error>.
+
 =head2 consume_bom
 
   # On a buffer which may begin with a BOM:
@@ -281,7 +325,7 @@ This is B<not> a locale-aware comparison.
 
 =head1 VERSION
 
-version 0.017_001
+version 0.017_002
 
 =head1 AUTHOR
 
